@@ -1,5 +1,5 @@
 /*
- * $Id: url.c,v 1.19.2.18 1996/07/08 18:31:11 wessels Exp $
+ * $Id: url.c,v 1.19.2.19 1996/08/12 06:33:27 wessels Exp $
  *
  * DEBUG: section 23    URL Parsing
  * AUTHOR: Duane Wessels
@@ -197,6 +197,10 @@ request_t *urlParse(method, url)
     protocol_t protocol = PROTO_NONE;
     proto[0] = host[0] = urlpath[0] = login[0] = '\0';
 
+    if (strlen(url) > MAX_URL) {
+	debug(23, 0, "urlParse: URL too large (%d bytes)\n", strlen(url));
+	return NULL;
+    }
     if (method == METHOD_CONNECT) {
 	port = CONNECT_PORT;
 	if (sscanf(url, "%[^:]:%d", host, &port) < 1)
