@@ -1,5 +1,5 @@
 /*
- * $Id: url.h,v 1.11.2.9 1996/07/08 18:34:15 wessels Exp $
+ * $Id: url.h,v 1.11.2.10 1996/07/25 21:43:47 wessels Exp $
  *
  * AUTHOR: Duane Wessels
  *
@@ -56,7 +56,7 @@ typedef enum {
 
 extern char *ProtocolStr[];
 
-typedef struct _request {
+struct _request {
     method_t method;
     protocol_t protocol;
     char login[MAX_LOGIN_SZ + 1];
@@ -64,7 +64,8 @@ typedef struct _request {
     int port;
     char urlpath[MAX_URL + 1];
     int link_count;		/* free when zero */
-} request_t;
+    hier_code hierarchy_code;
+};
 
 extern char *url_convert_hex _PARAMS((char *org_url, int allocate));
 extern char *url_escape _PARAMS((char *url));
